# -*- coding: utf-8 -*-
# file: batch_rgb_benchmark.py
# time: 13:26 04/06/2024
# author: YANG, HENG <hy345@exeter.ac.uk> (杨恒)
# github: https://github.com/yangheng95
# huggingface: https://huggingface.co/yangheng
# google scholar: https://scholar.google.com/citations?user=NPq5a_0AAAAJ&hl=en
# Copyright (C) 2019-2024. All Rights Reserved.
import random

from omnigenome import AutoBench
if __name__ == "__main__":
    from argparse import ArgumentParser
    parser = ArgumentParser()
    parser.add_argument("--gfm", type=str, default="genomic_foundation_models/OmniGenome-52M-1000")
    parser.add_argument("--benchmark", type=str, default="RGB")
    parser.add_argument("--batch_size", type=int, default=4)
    parser.add_argument("--patience", type=int, default=5)
    parser.add_argument("--epochs", type=int, default=20)
    parser.add_argument("--seeds", type=int, default=random.randint(0, 1000))
    parser.add_argument("--deepspeed", default="ds_config.json")
    args = parser.parse_args()

    gfms = [
        "yangheng/OmniGenome-v1.5",
    ]
    benchmark = "RGB"
    batch_size = 8
    epochs = 10
    patience = 5
    # max_examples = 100
    max_examples = None
    seeds = [random.randint(0, 1000) for _ in range(1)]
    for gfm in gfms:
        if 'multimolecule' in gfm:
            from multimolecule import RnaTokenizer, AutoModelForTokenPrediction
            tokenizer = RnaTokenizer.from_pretrained(gfm)
            gfm = AutoModelForTokenPrediction.from_pretrained(gfm, trust_remote_code=True).base_model
        else:
            tokenizer = None
        bench = AutoBench(
            benchmark=benchmark,
            model_name_or_path=gfm,
            tokenizer=tokenizer,
            overwrite=True,
            # trainer='accelerate',
            trainer='native',
            autocast='fp16'
        )
        bench.run(
            # The following parameters are optional and will override the default values
            batch_size=batch_size,
            gradient_accumulation_steps=1,
            max_examples=max_examples,
            patience=patience,
            seeds=seeds,
            epochs=epochs,
        )




#
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-68000 │ [0.5325] │  0.5325   │  0.5325  │   0   │   0   │ 0.5325 │ 0.5325 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-68000 │ [0.3822] │  0.3822   │  0.3822  │   0   │   0   │ 0.3822 │ 0.3822 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-68000 │ [0.6467] │  0.6467   │  0.6467  │   0   │   0   │ 0.6467 │ 0.6467 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-69000 │ [0.5229] │  0.5229   │  0.5229  │   0   │   0   │ 0.5229 │ 0.5229 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-69000 │ [0.3764] │  0.3764   │  0.3764  │   0   │   0   │ 0.3764 │ 0.3764 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-69000 │ [0.6474] │  0.6474   │  0.6474  │   0   │   0   │ 0.6474 │ 0.6474 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-70000 │ [0.5353] │  0.5353   │  0.5353  │   0   │   0   │ 0.5353 │ 0.5353 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-70000 │ [0.3891] │  0.3891   │  0.3891  │   0   │   0   │ 0.3891 │ 0.3891 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-70000 │ [0.6435] │  0.6435   │  0.6435  │   0   │   0   │ 0.6435 │ 0.6435 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
#
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-71000 │ [0.5181] │  0.5181   │  0.5181  │   0   │   0   │ 0.5181 │ 0.5181 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-71000 │ [0.3782] │  0.3782   │  0.3782  │   0   │   0   │ 0.3782 │ 0.3782 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-71000 │ [0.6418] │  0.6418   │  0.6418  │   0   │   0   │ 0.6418 │ 0.6418 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-72000 │ [0.5266] │  0.5266   │  0.5266  │   0   │   0   │ 0.5266 │ 0.5266 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-72000 │ [0.3753] │  0.3753   │  0.3753  │   0   │   0   │ 0.3753 │ 0.3753 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-72000 │ [0.6452] │  0.6452   │  0.6452  │   0   │   0   │ 0.6452 │ 0.6452 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
# -------------------------------------------------- Raw Metric Records --------------------------------------------------
# ╒═══════════════════╤═══════════════════════════════╤══════════╤═══════════╤══════════╤═══════╤═══════╤════════╤════════╕
# │ Metric            │ Trial                         │ Values   │  Average  │  Median  │  Std  │  IQR  │  Min   │  Max   │
# ╞═══════════════════╪═══════════════════════════════╪══════════╪═══════════╪══════════╪═══════╪═══════╪════════╪════════╡
# │ f1_score          │ RGB-RNA-SNMR-checkpoint-73000 │ [0.5129] │  0.5129   │  0.5129  │   0   │   0   │ 0.5129 │ 0.5129 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ matthews_corrcoef │ RGB-RNA-SNMR-checkpoint-73000 │ [0.3536] │  0.3536   │  0.3536  │   0   │   0   │ 0.3536 │ 0.3536 │
# ├───────────────────┼───────────────────────────────┼──────────┼───────────┼──────────┼───────┼───────┼────────┼────────┤
# │ roc_auc_score     │ RGB-RNA-SNMD-checkpoint-73000 │ [0.6452] │  0.6452   │  0.6452  │   0   │   0   │ 0.6452 │ 0.6452 │
# ╘═══════════════════╧═══════════════════════════════╧══════════╧═══════════╧══════════╧═══════╧═══════╧════════╧════════╛
# ------------------------------------ https://github.com/yangheng95/metric_visualizer ------------------------------------
